***********************
Contributing to MySmile
***********************

Reporting Issues
================
When reporting *bug* issues please describe problem, details, steps to reproduce,
version of operation system and browser. Such details helps us to reproduce issue and fix them faster.

Contributing policy
===================
To contribute please read `Guide to Start Contributing <https://guides.github.com/activities/contributing-to-open-source/>`_.

Please make sure that your code follows `PEP 8 <https://www.python.org/dev/peps/pep-0008/>`_ and covered by unit tests.

If you want to help please check the `list of open issues <https://github.com/MySmile/mysmile/issues>`_.
